Documentation
¶
Index ¶
- Constants
- func DecodeError(statusCode int, body []byte) error
- func IsAccessDenied(err error) bool
- func NewHTTPClient() *http.Client
- func NewTransport() *http.Transport
- type APIError
- type AddUserRequest
- type AddUserResponse
- type AttachRolePolicyRequest
- type AttachRolePolicyResponse
- type AttachUserPolicyRequest
- type AttachUserPolicyResponse
- type AttachedUserPolicy
- type CAMAccessKey
- type CAMAccessKeySecret
- type CDBAccount
- type CDBInstanceInfo
- type CDBRegionSellConf
- type CLSFilter
- type CLSLogset
- type CLSTag
- type CVMInstanceInfo
- type CVMRegionInfo
- type Client
- func (c *Client) AddUser(ctx context.Context, name, password string) (AddUserResponse, error)
- func (c *Client) AttachRolePolicy(ctx context.Context, roleName string, policyID uint64) (AttachRolePolicyResponse, error)
- func (c *Client) AttachUserPolicy(ctx context.Context, attachUin, policyID uint64) (AttachUserPolicyResponse, error)
- func (c *Client) CreateAccessKey(ctx context.Context, targetUin uint64) (CreateAccessKeyResponse, error)
- func (c *Client) CreateCDBAccounts(ctx context.Context, region, instanceID, user, host, password string) (CreateCDBAccountsResponse, error)
- func (c *Client) CreateRole(ctx context.Context, roleName, policyDocument string, ...) (CreateRoleResponse, error)
- func (c *Client) DeleteAccessKey(ctx context.Context, targetUin uint64, accessKeyID string) (DeleteAccessKeyResponse, error)
- func (c *Client) DeleteCDBAccounts(ctx context.Context, region, instanceID, user, host string) (DeleteCDBAccountsResponse, error)
- func (c *Client) DeleteRole(ctx context.Context, roleName string) (DeleteRoleResponse, error)
- func (c *Client) DeleteUser(ctx context.Context, name string, force uint64) (DeleteUserResponse, error)
- func (c *Client) DescribeAccountBalance(ctx context.Context, region string) (DescribeAccountBalanceResponse, error)
- func (c *Client) DescribeCDBAccounts(ctx context.Context, region, instanceID string) (DescribeCDBAccountsResponse, error)
- func (c *Client) DescribeCDBInstances(ctx context.Context, region string) (DescribeCDBInstancesResponse, error)
- func (c *Client) DescribeCDBZoneConfig(ctx context.Context, region string) (DescribeCDBZoneConfigResponse, error)
- func (c *Client) DescribeCVMInstances(ctx context.Context, region string, offset, limit int64) (DescribeCVMInstancesResponse, error)
- func (c *Client) DescribeCVMRegions(ctx context.Context, region string) (DescribeCVMRegionsResponse, error)
- func (c *Client) DescribeDomainList(ctx context.Context, region string, offset, limit int64) (DescribeDomainListResponse, error)
- func (c *Client) DescribeLighthouseInstances(ctx context.Context, region string, offset, limit int64) (DescribeLighthouseInstancesResponse, error)
- func (c *Client) DescribeLighthouseRegions(ctx context.Context, region string) (DescribeLighthouseRegionsResponse, error)
- func (c *Client) DescribeLogsets(ctx context.Context, region string, offset, limit uint64) (DescribeLogsetsResponse, error)
- func (c *Client) DescribeMariaDBInstances(ctx context.Context, region string) (DescribeMariaDBInstancesResponse, error)
- func (c *Client) DescribeMariaDBSaleInfo(ctx context.Context, region string) (DescribeMariaDBSaleInfoResponse, error)
- func (c *Client) DescribePostgresInstances(ctx context.Context, region string) (DescribePostgresInstancesResponse, error)
- func (c *Client) DescribePostgresRegions(ctx context.Context, region string) (DescribePostgresRegionsResponse, error)
- func (c *Client) DescribeRecordList(ctx context.Context, region, domain string, offset, limit uint64) (DescribeRecordListResponse, error)
- func (c *Client) DescribeSQLServerInstances(ctx context.Context, region string) (DescribeSQLServerInstancesResponse, error)
- func (c *Client) DescribeSQLServerRegions(ctx context.Context, region string) (DescribeSQLServerRegionsResponse, error)
- func (c *Client) DescribeSmsSignList(ctx context.Context, region string, signIDs []uint64) (DescribeSmsSignListResponse, error)
- func (c *Client) DescribeSmsTemplateList(ctx context.Context, region string, templateIDs []uint64) (DescribeSmsTemplateListResponse, error)
- func (c *Client) DescribeTATInvocationTasks(ctx context.Context, region string, invocationTaskIDs []string, ...) (DescribeTATInvocationTasksResponse, error)
- func (c *Client) DescribeTATInvocations(ctx context.Context, region string, invocationIDs []string) (DescribeTATInvocationsResponse, error)
- func (c *Client) DetachRolePolicy(ctx context.Context, roleName string, policyID uint64) (DetachRolePolicyResponse, error)
- func (c *Client) DetachUserPolicy(ctx context.Context, detachUin, policyID uint64) (DetachUserPolicyResponse, error)
- func (c *Client) Do(ctx context.Context, req Request, resp any) error
- func (c *Client) DoJSON(ctx context.Context, service string, version string, action string, ...) error
- func (c *Client) GetPolicy(ctx context.Context, policyID uint64) (GetPolicyResponse, error)
- func (c *Client) GetUser(ctx context.Context, name string) (GetUserResponse, error)
- func (c *Client) GetUserAppID(ctx context.Context) (GetUserAppIDResponse, error)
- func (c *Client) ListAccessKeys(ctx context.Context, targetUin uint64) (ListAccessKeysResponse, error)
- func (c *Client) ListAttachedUserAllPolicies(ctx context.Context, targetUin, page, rp, attachType uint64) (ListAttachedUserAllPoliciesResponse, error)
- func (c *Client) ListUsers(ctx context.Context) (ListUsersResponse, error)
- func (c *Client) LookUpEvents(ctx context.Context, region string, startTime, endTime int64, ...) (LookUpEventsResponse, error)
- func (c *Client) RunTATCommand(ctx context.Context, region, commandType, content string, instanceIDs []string) (RunTATCommandResponse, error)
- type CloudAuditEvent
- type CreateAccessKeyRequest
- type CreateAccessKeyResponse
- type CreateCDBAccountsRequest
- type CreateCDBAccountsResponse
- type CreateRoleRequest
- type CreateRoleResponse
- type DeleteAccessKeyRequest
- type DeleteAccessKeyResponse
- type DeleteCDBAccountsRequest
- type DeleteCDBAccountsResponse
- type DeleteRoleRequest
- type DeleteRoleResponse
- type DeleteUserRequest
- type DeleteUserResponse
- type DescribeAccountBalanceRequest
- type DescribeAccountBalanceResponse
- type DescribeCDBAccountsRequest
- type DescribeCDBAccountsResponse
- type DescribeCDBInstancesRequest
- type DescribeCDBInstancesResponse
- type DescribeCDBZoneConfigRequest
- type DescribeCDBZoneConfigResponse
- type DescribeCVMInstancesRequest
- type DescribeCVMInstancesResponse
- type DescribeCVMRegionsRequest
- type DescribeCVMRegionsResponse
- type DescribeDomainListRequest
- type DescribeDomainListResponse
- type DescribeLighthouseInstancesRequest
- type DescribeLighthouseInstancesResponse
- type DescribeLighthouseRegionsRequest
- type DescribeLighthouseRegionsResponse
- type DescribeLogsetsRequest
- type DescribeLogsetsResponse
- type DescribeMariaDBInstancesRequest
- type DescribeMariaDBInstancesResponse
- type DescribeMariaDBSaleInfoRequest
- type DescribeMariaDBSaleInfoResponse
- type DescribePostgresInstancesRequest
- type DescribePostgresInstancesResponse
- type DescribePostgresRegionsRequest
- type DescribePostgresRegionsResponse
- type DescribeRecordListRequest
- type DescribeRecordListResponse
- type DescribeSQLServerInstancesRequest
- type DescribeSQLServerInstancesResponse
- type DescribeSQLServerRegionsRequest
- type DescribeSQLServerRegionsResponse
- type DescribeSmsSignListRequest
- type DescribeSmsSignListResponse
- type DescribeSmsTemplateListRequest
- type DescribeSmsTemplateListResponse
- type DescribeTATInvocationTasksRequest
- type DescribeTATInvocationTasksResponse
- type DescribeTATInvocationsRequest
- type DescribeTATInvocationsResponse
- type DetachRolePolicyRequest
- type DetachRolePolicyResponse
- type DetachUserPolicyRequest
- type DetachUserPolicyResponse
- type DomainListItem
- type GetCallerIdentityRequest
- type GetCallerIdentityResponse
- type GetPolicyRequest
- type GetPolicyResponse
- type GetUserAppIDRequest
- type GetUserAppIDResponse
- type GetUserRequest
- type GetUserResponse
- type HTTPStatusError
- type LighthouseInstanceInfo
- type LighthouseRegionInfo
- type ListAccessKeysRequest
- type ListAccessKeysResponse
- type ListAttachedUserAllPoliciesRequest
- type ListAttachedUserAllPoliciesResponse
- type ListUsersRequest
- type ListUsersResponse
- type LookUpEventsRequest
- type LookUpEventsResponse
- type LookupAttribute
- type MariaDBInstanceInfo
- type MariaDBRegionInfo
- type Option
- type PostgresInstanceInfo
- type PostgresNetInfo
- type PostgresRegionInfo
- type RecordListItem
- type Request
- type RetryPolicy
- type RunTATCommandRequest
- type RunTATCommandResponse
- type SQLServerInstanceInfo
- type SQLServerRegionInfo
- type SignInput
- type Signature
- type SmsSignDetail
- type SmsTemplateDetail
- type SubAccountInfo
- type TATInvocation
- type TATInvocationTask
- type TATInvocationTaskBasic
- type TATTaskResult
- type TC3Signer
Constants ¶
const DefaultRegion = "ap-guangzhou"
const (
DefaultTimeout = 30 * time.Second
)
Variables ¶
This section is empty.
Functions ¶
func DecodeError ¶
func IsAccessDenied ¶ added in v0.2.5
func NewHTTPClient ¶
func NewTransport ¶
Types ¶
type AddUserRequest ¶
type AddUserResponse ¶
type AttachRolePolicyRequest ¶
type AttachRolePolicyResponse ¶
type AttachRolePolicyResponse struct {
Response struct {
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type AttachUserPolicyRequest ¶
type AttachUserPolicyResponse ¶
type AttachUserPolicyResponse struct {
Response struct {
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type AttachedUserPolicy ¶
type CAMAccessKey ¶ added in v0.3.1
type CAMAccessKeySecret ¶ added in v0.3.1
type CDBAccount ¶ added in v0.3.1
type CDBInstanceInfo ¶
type CDBInstanceInfo struct {
InstanceID *string `json:"InstanceId"`
EngineVersion *string `json:"EngineVersion"`
Region *string `json:"Region"`
WanStatus *int64 `json:"WanStatus"`
WanDomain *string `json:"WanDomain"`
WanPort *int64 `json:"WanPort"`
Vip *string `json:"Vip"`
Vport *int64 `json:"Vport"`
}
type CDBRegionSellConf ¶
type CDBRegionSellConf struct {
Region *string `json:"Region"`
}
type CLSLogset ¶ added in v0.3.1
type CLSLogset struct {
LogsetID *string `json:"LogsetId"`
LogsetName *string `json:"LogsetName"`
CreateTime *string `json:"CreateTime"`
AssumerName *string `json:"AssumerName"`
Tags []CLSTag `json:"Tags"`
TopicCount *uint64 `json:"TopicCount"`
RoleName *string `json:"RoleName"`
}
CLSLogset is the typed wire shape of a CLS logset entry. The CLS API uses pointer fields for every value; helper getters live in the driver to dereference them safely.
type CVMInstanceInfo ¶
type CVMRegionInfo ¶
type CVMRegionInfo struct {
Region *string `json:"Region"`
}
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func (*Client) AttachRolePolicy ¶
func (*Client) AttachUserPolicy ¶
func (*Client) CreateAccessKey ¶ added in v0.3.1
func (*Client) CreateCDBAccounts ¶ added in v0.3.1
func (*Client) CreateRole ¶
func (*Client) DeleteAccessKey ¶ added in v0.3.1
func (*Client) DeleteCDBAccounts ¶ added in v0.3.1
func (*Client) DeleteRole ¶
func (*Client) DeleteUser ¶
func (*Client) DescribeAccountBalance ¶
func (*Client) DescribeCDBAccounts ¶ added in v0.3.1
func (*Client) DescribeCDBInstances ¶
func (*Client) DescribeCDBZoneConfig ¶
func (*Client) DescribeCVMInstances ¶
func (*Client) DescribeCVMRegions ¶
func (*Client) DescribeDomainList ¶
func (*Client) DescribeLighthouseInstances ¶
func (*Client) DescribeLighthouseRegions ¶
func (*Client) DescribeLogsets ¶ added in v0.3.1
func (c *Client) DescribeLogsets(ctx context.Context, region string, offset, limit uint64) (DescribeLogsetsResponse, error)
DescribeLogsets queries the CLS logsets in a region. limit/offset paginate.
func (*Client) DescribeMariaDBInstances ¶
func (*Client) DescribeMariaDBSaleInfo ¶
func (*Client) DescribePostgresInstances ¶
func (*Client) DescribePostgresRegions ¶
func (*Client) DescribeRecordList ¶
func (*Client) DescribeSQLServerInstances ¶
func (*Client) DescribeSQLServerRegions ¶
func (*Client) DescribeSmsSignList ¶ added in v0.3.1
func (*Client) DescribeSmsTemplateList ¶ added in v0.3.1
func (*Client) DescribeTATInvocationTasks ¶
func (*Client) DescribeTATInvocations ¶
func (*Client) DetachRolePolicy ¶
func (*Client) DetachUserPolicy ¶
func (*Client) GetUserAppID ¶
func (c *Client) GetUserAppID(ctx context.Context) (GetUserAppIDResponse, error)
func (*Client) ListAccessKeys ¶ added in v0.3.1
func (*Client) ListAttachedUserAllPolicies ¶
func (*Client) ListUsers ¶
func (c *Client) ListUsers(ctx context.Context) (ListUsersResponse, error)
func (*Client) LookUpEvents ¶ added in v0.3.1
func (c *Client) LookUpEvents(ctx context.Context, region string, startTime, endTime int64, maxResults uint64, nextToken string) (LookUpEventsResponse, error)
LookUpEvents queries the Tencent CloudAudit operation log. The default caller behaviour mirrors the existing alibaba SAS dump: surface the most recent operations so a CSPM detection can be cross-referenced. StartTime / EndTime are unix seconds; pass 0 to leave them unset and fall back to the CloudAudit default lookback window.
func (*Client) RunTATCommand ¶
type CloudAuditEvent ¶ added in v0.3.1
type CloudAuditEvent struct {
EventID *string `json:"EventId"`
EventName *string `json:"EventName"`
EventNameCn *string `json:"EventNameCn"`
EventTime *string `json:"EventTime"`
EventRegion *string `json:"EventRegion"`
Username *string `json:"Username"`
SourceIPAddress *string `json:"SourceIPAddress"`
ResourceTypeCn *string `json:"ResourceTypeCn"`
ResourceName *string `json:"ResourceName"`
Status *uint64 `json:"Status"`
SecretID *string `json:"SecretId"`
APIVersion *string `json:"ApiVersion"`
}
type CreateAccessKeyRequest ¶ added in v0.3.1
type CreateAccessKeyRequest struct {
TargetUin *uint64 `json:"TargetUin,omitempty"`
}
type CreateAccessKeyResponse ¶ added in v0.3.1
type CreateAccessKeyResponse struct {
Response struct {
AccessKey CAMAccessKeySecret `json:"AccessKey"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type CreateCDBAccountsRequest ¶ added in v0.3.1
type CreateCDBAccountsRequest struct {
InstanceID *string `json:"InstanceId,omitempty"`
Accounts []CDBAccount `json:"Accounts,omitempty"`
Password *string `json:"Password,omitempty"`
Description *string `json:"Description,omitempty"`
}
type CreateCDBAccountsResponse ¶ added in v0.3.1
type CreateRoleRequest ¶
type CreateRoleResponse ¶
type DeleteAccessKeyRequest ¶ added in v0.3.1
type DeleteAccessKeyResponse ¶ added in v0.3.1
type DeleteAccessKeyResponse struct {
Response struct {
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DeleteCDBAccountsRequest ¶ added in v0.3.1
type DeleteCDBAccountsRequest struct {
InstanceID *string `json:"InstanceId,omitempty"`
Accounts []CDBAccount `json:"Accounts,omitempty"`
}
type DeleteCDBAccountsResponse ¶ added in v0.3.1
type DeleteRoleRequest ¶
type DeleteRoleRequest struct {
RoleName *string `json:"RoleName,omitempty"`
}
type DeleteRoleResponse ¶
type DeleteRoleResponse struct {
Response struct {
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DeleteUserRequest ¶
type DeleteUserResponse ¶
type DeleteUserResponse struct {
Response struct {
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeAccountBalanceRequest ¶
type DescribeAccountBalanceRequest struct{}
type DescribeCDBAccountsRequest ¶ added in v0.3.1
type DescribeCDBAccountsResponse ¶ added in v0.3.1
type DescribeCDBAccountsResponse struct {
Response struct {
TotalCount *int64 `json:"TotalCount"`
Items []CDBAccount `json:"Items"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeCDBInstancesRequest ¶
type DescribeCDBInstancesRequest struct{}
type DescribeCDBInstancesResponse ¶
type DescribeCDBInstancesResponse struct {
Response struct {
Items []CDBInstanceInfo `json:"Items"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeCDBZoneConfigRequest ¶
type DescribeCDBZoneConfigRequest struct{}
type DescribeCDBZoneConfigResponse ¶
type DescribeCDBZoneConfigResponse struct {
Response struct {
DataResult struct {
Regions []CDBRegionSellConf `json:"Regions"`
} `json:"DataResult"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeCVMInstancesResponse ¶
type DescribeCVMInstancesResponse struct {
Response struct {
TotalCount *int64 `json:"TotalCount"`
InstanceSet []CVMInstanceInfo `json:"InstanceSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeCVMRegionsRequest ¶
type DescribeCVMRegionsRequest struct{}
type DescribeCVMRegionsResponse ¶
type DescribeCVMRegionsResponse struct {
Response struct {
RegionSet []CVMRegionInfo `json:"RegionSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeDomainListResponse ¶
type DescribeDomainListResponse struct {
Response struct {
DomainCountInfo struct {
DomainTotal *uint64 `json:"DomainTotal"`
} `json:"DomainCountInfo"`
DomainList []DomainListItem `json:"DomainList"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeLighthouseInstancesResponse ¶
type DescribeLighthouseInstancesResponse struct {
Response struct {
TotalCount *int64 `json:"TotalCount"`
InstanceSet []LighthouseInstanceInfo `json:"InstanceSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeLighthouseRegionsRequest ¶
type DescribeLighthouseRegionsRequest struct{}
type DescribeLighthouseRegionsResponse ¶
type DescribeLighthouseRegionsResponse struct {
Response struct {
RegionSet []LighthouseRegionInfo `json:"RegionSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeLogsetsRequest ¶ added in v0.3.1
type DescribeLogsetsResponse ¶ added in v0.3.1
type DescribeMariaDBInstancesRequest ¶
type DescribeMariaDBInstancesRequest struct{}
type DescribeMariaDBInstancesResponse ¶
type DescribeMariaDBInstancesResponse struct {
Response struct {
Instances []MariaDBInstanceInfo `json:"Instances"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeMariaDBSaleInfoRequest ¶
type DescribeMariaDBSaleInfoRequest struct{}
type DescribeMariaDBSaleInfoResponse ¶
type DescribeMariaDBSaleInfoResponse struct {
Response struct {
RegionList []MariaDBRegionInfo `json:"RegionList"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribePostgresInstancesRequest ¶
type DescribePostgresInstancesRequest struct{}
type DescribePostgresInstancesResponse ¶
type DescribePostgresInstancesResponse struct {
Response struct {
DBInstanceSet []PostgresInstanceInfo `json:"DBInstanceSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribePostgresRegionsRequest ¶
type DescribePostgresRegionsRequest struct{}
type DescribePostgresRegionsResponse ¶
type DescribePostgresRegionsResponse struct {
Response struct {
RegionSet []PostgresRegionInfo `json:"RegionSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeRecordListResponse ¶
type DescribeRecordListResponse struct {
Response struct {
RecordCountInfo struct {
TotalCount *uint64 `json:"TotalCount"`
ListCount *uint64 `json:"ListCount"`
} `json:"RecordCountInfo"`
RecordList []RecordListItem `json:"RecordList"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeSQLServerInstancesRequest ¶
type DescribeSQLServerInstancesRequest struct{}
type DescribeSQLServerInstancesResponse ¶
type DescribeSQLServerInstancesResponse struct {
Response struct {
DBInstances []SQLServerInstanceInfo `json:"DBInstances"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeSQLServerRegionsRequest ¶
type DescribeSQLServerRegionsRequest struct{}
type DescribeSQLServerRegionsResponse ¶
type DescribeSQLServerRegionsResponse struct {
Response struct {
RegionSet []SQLServerRegionInfo `json:"RegionSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeSmsSignListRequest ¶ added in v0.3.1
type DescribeSmsSignListResponse ¶ added in v0.3.1
type DescribeSmsSignListResponse struct {
Response struct {
DescribeSignListStatusSet []SmsSignDetail `json:"DescribeSignListStatusSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeSmsTemplateListRequest ¶ added in v0.3.1
type DescribeSmsTemplateListResponse ¶ added in v0.3.1
type DescribeSmsTemplateListResponse struct {
Response struct {
DescribeTemplateStatusSet []SmsTemplateDetail `json:"DescribeTemplateStatusSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeTATInvocationTasksResponse ¶
type DescribeTATInvocationTasksResponse struct {
Response struct {
InvocationTaskSet []TATInvocationTask `json:"InvocationTaskSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DescribeTATInvocationsRequest ¶
type DescribeTATInvocationsRequest struct {
InvocationIDs []string `json:"InvocationIds,omitempty"`
}
type DescribeTATInvocationsResponse ¶
type DescribeTATInvocationsResponse struct {
Response struct {
InvocationSet []TATInvocation `json:"InvocationSet"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DetachRolePolicyRequest ¶
type DetachRolePolicyResponse ¶
type DetachRolePolicyResponse struct {
Response struct {
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DetachUserPolicyRequest ¶
type DetachUserPolicyResponse ¶
type DetachUserPolicyResponse struct {
Response struct {
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type DomainListItem ¶
type GetCallerIdentityRequest ¶
type GetCallerIdentityRequest struct{}
type GetPolicyRequest ¶
type GetPolicyRequest struct {
PolicyID *uint64 `json:"PolicyId,omitempty"`
}
type GetPolicyResponse ¶
type GetUserAppIDRequest ¶
type GetUserAppIDRequest struct{}
type GetUserAppIDResponse ¶
type GetUserRequest ¶
type GetUserRequest struct {
Name *string `json:"Name,omitempty"`
}
type GetUserResponse ¶
type HTTPStatusError ¶
func (*HTTPStatusError) Error ¶
func (e *HTTPStatusError) Error() string
type LighthouseInstanceInfo ¶
type LighthouseInstanceInfo struct {
InstanceID *string `json:"InstanceId"`
InstanceName *string `json:"InstanceName"`
InstanceState *string `json:"InstanceState"`
PublicAddresses []string `json:"PublicAddresses"`
PrivateAddresses []string `json:"PrivateAddresses"`
PlatformType *string `json:"PlatformType"`
}
type LighthouseRegionInfo ¶
type LighthouseRegionInfo struct {
Region *string `json:"Region"`
}
type ListAccessKeysRequest ¶ added in v0.3.1
type ListAccessKeysRequest struct {
TargetUin *uint64 `json:"TargetUin,omitempty"`
}
type ListAccessKeysResponse ¶ added in v0.3.1
type ListAccessKeysResponse struct {
Response struct {
AccessKeys []CAMAccessKey `json:"AccessKeys"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type ListAttachedUserAllPoliciesRequest ¶
type ListAttachedUserAllPoliciesRequest struct {
TargetUin *uint64 `json:"TargetUin,omitempty"`
Rp *uint64 `json:"Rp,omitempty"`
Page *uint64 `json:"Page,omitempty"`
AttachType *uint64 `json:"AttachType,omitempty"`
StrategyType *uint64 `json:"StrategyType,omitempty"`
Keyword *string `json:"Keyword,omitempty"`
}
type ListAttachedUserAllPoliciesResponse ¶
type ListAttachedUserAllPoliciesResponse struct {
Response struct {
PolicyList []AttachedUserPolicy `json:"PolicyList"`
TotalNum *uint64 `json:"TotalNum"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type ListUsersRequest ¶
type ListUsersRequest struct{}
type ListUsersResponse ¶
type ListUsersResponse struct {
Response struct {
Data []SubAccountInfo `json:"Data"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type LookUpEventsRequest ¶ added in v0.3.1
type LookUpEventsRequest struct {
StartTime *int64 `json:"StartTime,omitempty"`
EndTime *int64 `json:"EndTime,omitempty"`
MaxResults *uint64 `json:"MaxResults,omitempty"`
NextToken *string `json:"NextToken,omitempty"`
LookupAttributes []LookupAttribute `json:"LookupAttributes,omitempty"`
}
type LookUpEventsResponse ¶ added in v0.3.1
type LookUpEventsResponse struct {
Response struct {
NextToken *string `json:"NextToken"`
ListOver *bool `json:"ListOver"`
Events []CloudAuditEvent `json:"Events"`
RequestID string `json:"RequestId"`
} `json:"Response"`
}
type LookupAttribute ¶ added in v0.3.1
type MariaDBInstanceInfo ¶
type MariaDBInstanceInfo struct {
InstanceID *string `json:"InstanceId"`
DBVersion *string `json:"DbVersion"`
Region *string `json:"Region"`
WanStatus *int64 `json:"WanStatus"`
WanDomain *string `json:"WanDomain"`
WanPort *int64 `json:"WanPort"`
Vip *string `json:"Vip"`
Vport *int64 `json:"Vport"`
}
type MariaDBRegionInfo ¶
type MariaDBRegionInfo struct {
Region *string `json:"Region"`
}
type Option ¶
type Option func(*Client)
func WithBaseURL ¶
func WithHTTPClient ¶
func WithLanguage ¶
func WithRequestClient ¶
func WithRetryPolicy ¶
func WithRetryPolicy(policy RetryPolicy) Option
type PostgresInstanceInfo ¶
type PostgresInstanceInfo struct {
DBInstanceID *string `json:"DBInstanceId"`
DBEngine *string `json:"DBEngine"`
DBInstanceVersion *string `json:"DBInstanceVersion"`
Region *string `json:"Region"`
DBInstanceNetInfo []PostgresNetInfo `json:"DBInstanceNetInfo"`
}
type PostgresNetInfo ¶
type PostgresRegionInfo ¶
type RecordListItem ¶
type RetryPolicy ¶
type RetryPolicy = httpclient.RetryPolicy
func DefaultRetryPolicy ¶
func DefaultRetryPolicy() RetryPolicy
type RunTATCommandRequest ¶
type RunTATCommandResponse ¶
type SQLServerInstanceInfo ¶
type SQLServerInstanceInfo struct {
InstanceID *string `json:"InstanceId"`
VersionName *string `json:"VersionName"`
Version *string `json:"Version"`
Region *string `json:"Region"`
DNSPodDomain *string `json:"DnsPodDomain"`
TgwWanVPort *int64 `json:"TgwWanVPort"`
Vip *string `json:"Vip"`
Vport *int64 `json:"Vport"`
}
type SQLServerRegionInfo ¶
type SmsSignDetail ¶ added in v0.3.1
type SmsTemplateDetail ¶ added in v0.3.1
type SmsTemplateDetail struct {
TemplateID *uint64 `json:"TemplateId"`
TemplateName *string `json:"TemplateName"`
TemplateContent *string `json:"TemplateContent"`
StatusCode *int `json:"StatusCode"`
ReviewReply *string `json:"ReviewReply"`
CreateTime *int64 `json:"CreateTime"`
International *uint64 `json:"International"`
}
type SubAccountInfo ¶
type TATInvocation ¶
type TATInvocation struct {
InvocationID *string `json:"InvocationId"`
InvocationTaskBasicInfoSet []TATInvocationTaskBasic `json:"InvocationTaskBasicInfoSet"`
}
type TATInvocationTask ¶
type TATInvocationTaskBasic ¶
type TATTaskResult ¶
Click to show internal directories.
Click to hide internal directories.