Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ErrNoSuchKey ¶
type ErrNoSuchKey struct {
Name string
}
ErrNoSuchKey means no such key exists in metadata.
func (*ErrNoSuchKey) Error ¶
func (e *ErrNoSuchKey) Error() string
Error returns the value of the metadata key
type Provider ¶
type Provider interface {
// Name returns the name of the provider
Name() string
// Resources returns the provider for an resource deployment source.
Resources(ctx context.Context) (*Resources, error)
UserManagement(action, uname, pwd string)
BucketDump(action, bucketname string)
}
Provider is an interface implemented by any cloud service provider.
It provides the bare minimum of methods to allow complete overview of user data.
type Resources ¶
type Sms ¶ added in v0.0.6
type Sms struct {
Signs []SmsSign
Templates []SmsTemplate
DailySize int64
}
type SmsTemplate ¶ added in v0.0.6
Click to show internal directories.
Click to hide internal directories.